@@ -72,8 +72,8 @@ class Hydroplane:
         
     def simple_hydro(self):
         hydro_top_navigation = self.hydro_components_navigation.hydro_top_navigation(toggle=False)
-        hydro.layout = self.hydro_wireframe(self.hydro_top_navigation)
-        hydro.run_server(host="0.0.0.0", port="8053", debug=self.hydro_debug, threaded=self.hydro_threaded)
+        hydro.layout = self.hydro_wireframe(hydro_top_navigation)
+        hydro.run_server(host="0.0.0.0", port="8059", debug=self.hydro_debug, threaded=self.hydro_threaded)
 
     def start_up(self):
         # check if postgres is available, if not then wait and retry 
